@@ -19,7 +19,7 @@
 
 #include "parsedatetimetest.h"
 
-#include <qtest.h>
+#include <QTest>
 
 #include <kmime_header_parsing.h>
 
