@@ -328,7 +328,7 @@ QByteArray MailboxList::as7BitString(bool withHeaderType) const
     if (withHeaderType) {
         rv = typeIntro();
     }
-    foreach (const Types::Mailbox &mbox, d->mailboxList) {
+    for (const Types::Mailbox &mbox : qAsConst(d->mailboxList)) {
         rv += mbox.as7BitString(d->encCS);
         rv += ", ";
     }
@@ -391,7 +391,7 @@ QStringList MailboxList::displayNames() const
     Q_D(const MailboxList);
     QStringList rv;
     rv.reserve(d->mailboxList.count());
-    foreach (const Types::Mailbox &mbox, d->mailboxList) {
+    for (const Types::Mailbox &mbox : qAsConst(d->mailboxList)) {
         if (mbox.hasName())
             rv.append(mbox.name());
         else
@@ -436,7 +436,7 @@ bool MailboxList::parse(const char *&scursor, const char *const send,
     d->mailboxList.reserve(maybeAddressList.count());
 
     // extract the mailboxes and complain if there are groups:
-    foreach (const auto &it, maybeAddressList) {
+    for (const auto &it : qAsConst(maybeAddressList)) {
         if (!(it).displayName.isEmpty()) {
             KMIME_WARN << "mailbox groups in header disallowing them! Name: \""
                        << (it).displayName << "\""
@@ -500,8 +500,9 @@ QByteArray AddressList::as7BitString(bool withHeaderType) const
     if (withHeaderType) {
         rv = typeIntro();
     }
-    foreach (const Types::Address &addr, d->addressList) {
-        foreach (const Types::Mailbox &mbox, addr.mailboxList) {
+    for (const Types::Address &addr : qAsConst(d->addressList)) {
+        const auto mailBoxList = addr.mailboxList;
+        for (const Types::Mailbox &mbox : mailBoxList) {
             rv += mbox.as7BitString(d->encCS);
             rv += ", ";
         }
@@ -521,7 +522,7 @@ QString AddressList::asUnicodeString() const
 {
     Q_D(const AddressList);
     QStringList rv;
-    foreach (const Types::Address &addr, d->addressList) {
+    for (const Types::Address &addr : qAsConst(d->addressList)) {
         rv.reserve(rv.size() + addr.mailboxList.size());
         foreach (const Types::Mailbox &mbox, addr.mailboxList) {
             rv.append(mbox.prettyAddress());
@@ -576,8 +577,9 @@ QStringList AddressList::displayNames() const
 {
     Q_D(const AddressList);
     QStringList rv;
-    foreach (const Types::Address &addr, d->addressList) {
-        foreach (const Types::Mailbox &mbox, addr.mailboxList) {
+    for (const Types::Address &addr : qAsConst(d->addressList)) {
+        const auto mailboxList = addr.mailboxList;
+        for (const Types::Mailbox &mbox : mailboxList) {
             if (mbox.hasName())
                 rv.append(mbox.name());
             else
@@ -952,7 +954,7 @@ QByteArray Ident::as7BitString(bool withHeaderType) const
     if (withHeaderType) {
         rv = typeIntro();
     }
-    foreach (const Types::AddrSpec &addr, d->msgIdList) {
+    for (const Types::AddrSpec &addr : qAsConst(d->msgIdList)) {
         if (!addr.isEmpty()) {
             const QString asString = addr.asString();
             rv += '<';
