@@ -137,18 +137,19 @@ public:
       Parses the given string. Take care of RFC2047-encoded strings.
       @param s The encoded header data.
     */
+    virtual void from7BitString(const char *s, size_t len);
     virtual void from7BitString(const QByteArray &s) = 0;
 
     /**
       Returns the encoded header.
       @param withHeaderType Specifies whether the header-type should be included.
     */
-    virtual QByteArray as7BitString(bool withHeaderType = true) const = 0;
+    Q_REQUIRED_RESULT virtual QByteArray as7BitString(bool withHeaderType = true) const = 0;
 
     /**
       Returns the charset that is used for RFC2047-encoding.
     */
-    QByteArray rfc2047Charset() const;
+    Q_REQUIRED_RESULT QByteArray rfc2047Charset() const;
 
     /**
       Sets the charset for RFC2047-encoding.
@@ -190,12 +191,12 @@ public:
     /**
       Checks if this header is of type @p t.
     */
-    bool is(const char *t) const;
+    Q_REQUIRED_RESULT bool is(const char *t) const;
 
     /**
       Checks if this header is a MIME header.
     */
-    bool isMimeHeader() const;
+    Q_REQUIRED_RESULT bool isMimeHeader() const;
 
 protected:
     /**
@@ -246,6 +247,7 @@ public:
     Unstructured();
     ~Unstructured();
 
+    using Base::from7BitString;
     void from7BitString(const QByteArray &s) override;
     QByteArray as7BitString(bool withHeaderType = true) const override;
 
@@ -298,6 +300,7 @@ public:
     Structured();
     ~Structured();
 
+    void from7BitString(const char *s, size_t len) override;
     void from7BitString(const QByteArray &s) override;
     QString asUnicodeString() const override;
     void fromUnicodeString(const QString &s, const QByteArray &b) override;
@@ -514,6 +517,11 @@ public:
     void clear() override;
     bool isEmpty() const override;
 
+    /**
+      Initialize this identifier Copy the data from
+     */
+    void fromIdent(const Ident* ident);
+
     /**
       Returns the list of identifiers contained in this header.
       Note:
@@ -1013,7 +1021,7 @@ public:
     QByteArray subType() const;
 
     /**
-      Sets the mimetype and clears already existing parameters.
+      Sets the mimetype.
       @param mimeType The new mimetype.
     */
     void setMimeType(const QByteArray &mimeType);
@@ -1202,7 +1210,7 @@ class KMIME_EXPORT Generic : public Generics::Unstructured
 {
 public:
     Generic();
-    Generic(const char *t);
+    Generic(const char *t, int len = -1);
     ~Generic();
 
     void clear() override;
@@ -1211,7 +1219,7 @@ public:
 
     const char *type() const override;
 
-    void setType(const char *type);
+    void setType(const char *type, int len = -1);
 
 private:
     Q_DECLARE_PRIVATE(Generic)
