@@ -61,12 +61,12 @@ Content *Message::mainBodyPart(const QByteArray &type)
             if (contentType->mimeType() == type || type.isEmpty()) {
                 return c;
             }
-            return 0;
+            return nullptr;
         }
 
         // empty multipart
-        if (c->contents().count() == 0) {
-            return 0;
+        if (c->contents().isEmpty()) {
+            return nullptr;
         }
 
         // multipart/alternative
@@ -74,18 +74,19 @@ Content *Message::mainBodyPart(const QByteArray &type)
             if (type.isEmpty()) {
                 return c->contents().at(0);
             }
-            foreach (Content *c1, c->contents()) {
+            const auto contents = c->contents();
+            for (Content *c1 : contents) {
                 if (c1->contentType()->mimeType() == type) {
                     return c1;
                 }
             }
-            return 0;
+            return nullptr;
         }
 
         c = c->contents().at(0);
     }
 
-    return 0;
+    return nullptr;
 }
 
 QString Message::mimeType()
